@@ -7,22 +7,22 @@
 
 #include <OSL/encodedtypes.h>
 #include <OSL/genclosure.h>
+#include <OSL/hashes.h>
 #include <OSL/journal.h>
 #include <OSL/oslexec.h>
 
 #include "simplerend.h"
 
 
-// Instance all global string variables used by SimpleRend.cpp or
-// rs_simplerend.cpp (free functions).
-// NOTE:  C linkage with a "RS_" prefix is used to allow for unmangled
-// non-colliding global symbol names, so its easier to pass them to
-// OSL::register_JIT_Global(name, addr) for host execution
-extern "C" {
-#define RS_STRDECL(str, var_name) OSL::ustring RS_##var_name { str };
+// Create ustrings for all strings used by the free function renderer services.
+// Required to allow the reverse mapping of hash->string to work when processing messages
+namespace RS {
+namespace Strings {
+#define RS_STRDECL(str, var_name) const OSL::ustring var_name { str };
 #include "rs_strdecls.h"
 #undef RS_STRDECL
-}
+}  // namespace Strings
+}  // namespace RS
 
 
 using namespace OSL;
@@ -109,13 +109,8 @@ struct ParameterTestParams {
 }  // anonymous namespace
 
 
-OSL_NAMESPACE_ENTER
+OSL_NAMESPACE_BEGIN
 
-static ustring u_camera("camera"), u_screen("screen");
-static ustring u_NDC("NDC"), u_raster("raster");
-static ustring u_perspective("perspective");
-static ustring u_s("s"), u_t("t");
-static ustring u_red("red"), u_green("green"), u_blue("blue");
 static TypeDesc TypeFloatArray2(TypeDesc::FLOAT, 2);
 static TypeDesc TypeFloatArray4(TypeDesc::FLOAT, 4);
 static TypeDesc TypeIntArray2(TypeDesc::INT, 2);
@@ -223,34 +218,36 @@ register_closures(OSL::ShadingSystem* shadingsys)
 
 SimpleRenderer::SimpleRenderer()
 #if OSL_USE_BATCHED
-    : m_batch_16_simple_renderer(*this), m_batch_8_simple_renderer(*this)
+    : m_batch_16_simple_renderer(*this)
+    , m_batch_8_simple_renderer(*this)
+    , m_batch_4_simple_renderer(*this)
 #endif
 {
     Matrix44 M;
     M.makeIdentity();
-    camera_params(M, u_perspective, 90.0f, 0.1f, 1000.0f, 256, 256);
+    camera_params(M, RS::Hashes::perspective, 90.0f, 0.1f, 1000.0f, 256, 256);
 
     // Set up getters
-    m_attr_getters[ustring("osl:version")] = &SimpleRenderer::get_osl_version;
-    m_attr_getters[ustring("camera:resolution")]
+    m_attr_getters[RS::Hashes::osl_version] = &SimpleRenderer::get_osl_version;
+    m_attr_getters[RS::Hashes::camera_resolution]
         = &SimpleRenderer::get_camera_resolution;
-    m_attr_getters[ustring("camera:projection")]
+    m_attr_getters[RS::Hashes::camera_projection]
         = &SimpleRenderer::get_camera_projection;
-    m_attr_getters[ustring("camera:pixelaspect")]
+    m_attr_getters[RS::Hashes::camera_pixelaspect]
         = &SimpleRenderer::get_camera_pixelaspect;
-    m_attr_getters[ustring("camera:screen_window")]
+    m_attr_getters[RS::Hashes::camera_screen_window]
         = &SimpleRenderer::get_camera_screen_window;
-    m_attr_getters[ustring("camera:fov")]  = &SimpleRenderer::get_camera_fov;
-    m_attr_getters[ustring("camera:clip")] = &SimpleRenderer::get_camera_clip;
-    m_attr_getters[ustring("camera:clip_near")]
+    m_attr_getters[RS::Hashes::camera_fov]  = &SimpleRenderer::get_camera_fov;
+    m_attr_getters[RS::Hashes::camera_clip] = &SimpleRenderer::get_camera_clip;
+    m_attr_getters[RS::Hashes::camera_clip_near]
         = &SimpleRenderer::get_camera_clip_near;
-    m_attr_getters[ustring("camera:clip_far")]
+    m_attr_getters[RS::Hashes::camera_clip_far]
         = &SimpleRenderer::get_camera_clip_far;
-    m_attr_getters[ustring("camera:shutter")]
+    m_attr_getters[RS::Hashes::camera_shutter]
         = &SimpleRenderer::get_camera_shutter;
-    m_attr_getters[ustring("camera:shutter_open")]
+    m_attr_getters[RS::Hashes::camera_shutter_open]
         = &SimpleRenderer::get_camera_shutter_open;
-    m_attr_getters[ustring("camera:shutter_close")]
+    m_attr_getters[RS::Hashes::camera_shutter_close]
         = &SimpleRenderer::get_camera_shutter_close;
 }
 
@@ -263,6 +260,8 @@ SimpleRenderer::supports(string_view feature) const
 {
     if (m_use_rs_bitcode && feature == "build_attribute_getter")
         return true;
+    else if (m_use_rs_bitcode && feature == "build_interpolated_getter")
+        return true;
     return false;
 }
 
@@ -309,16 +308,12 @@ SimpleRenderer::attribute(string_view name, TypeDesc type, const void* value)
 void
 SimpleRenderer::register_JIT_Global_Variables()  //callable from testshade
 {
-#define RS_STRDECL(str, var_name) \
-    OSL::register_JIT_Global(__OSL_STRINGIFY(RS_##var_name), &RS_##var_name);
-#include "rs_strdecls.h"
-#undef RS_STRDECL
 }
 
 
 void
 SimpleRenderer::camera_params(const Matrix44& world_to_camera,
-                              ustring projection, float hfov, float hither,
+                              ustringhash projection, float hfov, float hither,
                               float yon, int xres, int yres)
 {
     m_world_to_camera  = world_to_camera;
@@ -400,11 +395,13 @@ bool
 SimpleRenderer::get_inverse_matrix(ShaderGlobals* /*sg*/, Matrix44& result,
                                    ustringhash to, float /*time*/)
 {
-    if (to == u_camera || to == u_screen || to == u_NDC || to == u_raster) {
+    if (to == OSL::Hashes::camera || to == OSL::Hashes::screen
+        || to == OSL::Hashes::NDC || to == RS::Hashes::raster) {
         Matrix44 M = m_world_to_camera;
-        if (to == u_screen || to == u_NDC || to == u_raster) {
+        if (to == OSL::Hashes::screen || to == OSL::Hashes::NDC
+            || to == RS::Hashes::raster) {
             float depthrange = (double)m_yon - (double)m_hither;
-            if (m_projection == u_perspective) {
+            if (m_projection == RS::Hashes::perspective) {
                 float tanhalffov = tanf(0.5f * m_fov * M_PI / 180.0);
                 Matrix44 camera_to_screen(1 / tanhalffov, 0, 0, 0, 0,
                                           1 / tanhalffov, 0, 0, 0, 0,
@@ -417,7 +414,7 @@ SimpleRenderer::get_inverse_matrix(ShaderGlobals* /*sg*/, Matrix44& result,
                                           -m_hither / depthrange, 1);
                 M = M * camera_to_screen;
             }
-            if (to == u_NDC || to == u_raster) {
+            if (to == OSL::Hashes::NDC || to == RS::Hashes::raster) {
                 float screenleft = -1.0, screenwidth = 2.0;
                 float screenbottom = -1.0, screenheight = 2.0;
                 Matrix44 screen_to_ndc(1 / screenwidth, 0, 0, 0, 0,
@@ -425,7 +422,7 @@ SimpleRenderer::get_inverse_matrix(ShaderGlobals* /*sg*/, Matrix44& result,
                                        -screenleft / screenwidth,
                                        -screenbottom / screenheight, 0, 1);
                 M = M * screen_to_ndc;
-                if (to == u_raster) {
+                if (to == RS::Hashes::raster) {
                     Matrix44 ndc_to_raster(m_xres, 0, 0, 0, 0, m_yres, 0, 0, 0,
                                            0, 1, 0, 0, 0, 0, 1);
                     M = M * ndc_to_raster;
@@ -470,12 +467,14 @@ SimpleRenderer::get_array_attribute(ShaderGlobals* sg, bool derivatives,
 
     // In order to test getattribute(), respond positively to
     // "options"/"blahblah"
-    if (object == "options" && name == "blahblah" && type == TypeFloat) {
+    if (object == RS::Hashes::options && name == RS::Hashes::blahblah
+        && type == TypeFloat) {
         *(float*)val = 3.14159;
         return true;
     }
 
-    if (object.empty() && name == "shading:index" && type == TypeInt) {
+    if (object.empty() && name == RS::Hashes::shading_index
+        && type == TypeInt) {
         *(int*)val = OSL::get_shade_index(sg);
         return true;
     }
@@ -509,7 +508,11 @@ SimpleRenderer::get_userdata(bool derivatives, ustringhash name, TypeDesc type,
     // look up something specific to the primitive, rather than have hard-
     // coded names.
 
-    if (name == u_s && type == TypeFloat) {
+    if (name == RS::Hashes::face_idx && type == TypeInt) {
+        ((int*)val)[0] = int(4 * sg->u);
+        return true;
+    }
+    if (name == RS::Hashes::s && type == TypeFloat) {
         ((float*)val)[0] = sg->u;
         if (derivatives) {
             ((float*)val)[1] = sg->dudx;
@@ -517,7 +520,7 @@ SimpleRenderer::get_userdata(bool derivatives, ustringhash name, TypeDesc type,
         }
         return true;
     }
-    if (name == u_t && type == TypeFloat) {
+    if (name == RS::Hashes::t && type == TypeFloat) {
         ((float*)val)[0] = sg->v;
         if (derivatives) {
             ((float*)val)[1] = sg->dvdx;
@@ -525,7 +528,7 @@ SimpleRenderer::get_userdata(bool derivatives, ustringhash name, TypeDesc type,
         }
         return true;
     }
-    if (name == u_red && type == TypeFloat && sg->P.x > 0.5f) {
+    if (name == RS::Hashes::red && type == TypeFloat && sg->P.x > 0.5f) {
         ((float*)val)[0] = sg->u;
         if (derivatives) {
             ((float*)val)[1] = sg->dudx;
@@ -533,7 +536,7 @@ SimpleRenderer::get_userdata(bool derivatives, ustringhash name, TypeDesc type,
         }
         return true;
     }
-    if (name == u_green && type == TypeFloat && sg->P.x < 0.5f) {
+    if (name == RS::Hashes::green && type == TypeFloat && sg->P.x < 0.5f) {
         ((float*)val)[0] = sg->v;
         if (derivatives) {
             ((float*)val)[1] = sg->dvdx;
@@ -541,7 +544,7 @@ SimpleRenderer::get_userdata(bool derivatives, ustringhash name, TypeDesc type,
         }
         return true;
     }
-    if (name == u_blue && type == TypeFloat
+    if (name == RS::Hashes::blue && type == TypeFloat
         && ((static_cast<int>(sg->P.y * 12) % 2) == 0)) {
         ((float*)val)[0] = 1.0f - sg->u;
         if (derivatives) {
@@ -551,9 +554,16 @@ SimpleRenderer::get_userdata(bool derivatives, ustringhash name, TypeDesc type,
         return true;
     }
 
-    if (const OIIO::ParamValue* p = userdata.find_pv(name, type)) {
+    if (const OIIO::ParamValue* p = userdata.find_pv(ustring_from(name), type)) {
         size_t size = p->type().size();
-        memcpy(val, p->data(), size);
+
+        if (p->type() == TypeDesc::STRING) {
+            const ustringhash* uh_data = reinterpret_cast<const ustringhash*>(
+                p->data());
+            memcpy(val, uh_data, size);
+        } else {
+            memcpy(val, p->data(), size);
+        }
         if (derivatives)
             memset((char*)val + size, 0, 2 * size);
         return true;
@@ -656,10 +666,10 @@ SimpleRenderer::build_attribute_getter(
                    && *attribute_name == ustring("shading:index")
                    && type == OSL::TypeInt) {
             spec.set(rs_get_shade_index,
-                     AttributeSpecBuiltinArg::ShaderGlobalsPointer);
+                     AttributeSpecBuiltinArg::OpaqueExecutionContext);
         } else {
             spec.set(rs_get_attribute,
-                     AttributeSpecBuiltinArg::ShaderGlobalsPointer,
+                     AttributeSpecBuiltinArg::OpaqueExecutionContext,
                      AttributeSpecBuiltinArg::ObjectName,
                      AttributeSpecBuiltinArg::AttributeName,
                      AttributeSpecBuiltinArg::Type,
@@ -669,6 +679,118 @@ SimpleRenderer::build_attribute_getter(
     }
 }
 
+
+void
+SimpleRenderer::build_interpolated_getter(const ShaderGroup& group,
+                                          const ustring& param_name,
+                                          TypeDesc type, bool derivatives,
+                                          InterpolatedGetterSpec& spec)
+{
+    static const OIIO::ustring rs_get_interpolated_face_idx(
+        "rs_get_interpolated_face_idx");
+    static const OIIO::ustring rs_get_interpolated_s("rs_get_interpolated_s");
+    static const OIIO::ustring rs_get_interpolated_t("rs_get_interpolated_t");
+    static const OIIO::ustring rs_get_interpolated_red(
+        "rs_get_interpolated_red");
+    static const OIIO::ustring rs_get_interpolated_green(
+        "rs_get_interpolated_green");
+    static const OIIO::ustring rs_get_interpolated_blue(
+        "rs_get_interpolated_blue");
+    static const OIIO::ustring rs_get_interpolated_test(
+        "rs_get_interpolated_test");
+
+    static const OIIO::ustring rs_get_attribute_constant_int(
+        "rs_get_attribute_constant_int");
+    static const OIIO::ustring rs_get_attribute_constant_int2(
+        "rs_get_attribute_constant_int2");
+    static const OIIO::ustring rs_get_attribute_constant_int3(
+        "rs_get_attribute_constant_int3");
+    static const OIIO::ustring rs_get_attribute_constant_int4(
+        "rs_get_attribute_constant_int4");
+
+    static const OIIO::ustring rs_get_attribute_constant_float(
+        "rs_get_attribute_constant_float");
+    static const OIIO::ustring rs_get_attribute_constant_float2(
+        "rs_get_attribute_constant_float2");
+    static const OIIO::ustring rs_get_attribute_constant_float3(
+        "rs_get_attribute_constant_float3");
+    static const OIIO::ustring rs_get_attribute_constant_float4(
+        "rs_get_attribute_constant_float4");
+
+    if (param_name == RS::Hashes::face_idx && type == OIIO::TypeInt) {
+        spec.set(rs_get_interpolated_face_idx,
+                 InterpolatedSpecBuiltinArg::OpaqueExecutionContext);
+    } else if (param_name == RS::Hashes::s && type == OIIO::TypeFloat) {
+        spec.set(rs_get_interpolated_s,
+                 InterpolatedSpecBuiltinArg::OpaqueExecutionContext,
+                 InterpolatedSpecBuiltinArg::Derivatives);
+    } else if (param_name == RS::Hashes::t && type == OIIO::TypeFloat) {
+        spec.set(rs_get_interpolated_t,
+                 InterpolatedSpecBuiltinArg::OpaqueExecutionContext,
+                 InterpolatedSpecBuiltinArg::Derivatives);
+    } else if (param_name == RS::Hashes::red && type == OIIO::TypeFloat) {
+        spec.set(rs_get_interpolated_red,
+                 InterpolatedSpecBuiltinArg::OpaqueExecutionContext,
+                 InterpolatedSpecBuiltinArg::Derivatives);
+    } else if (param_name == RS::Hashes::green && type == OIIO::TypeFloat) {
+        spec.set(rs_get_interpolated_green,
+                 InterpolatedSpecBuiltinArg::OpaqueExecutionContext,
+                 InterpolatedSpecBuiltinArg::Derivatives);
+    } else if (param_name == RS::Hashes::blue && type == OIIO::TypeFloat) {
+        spec.set(rs_get_interpolated_blue,
+                 InterpolatedSpecBuiltinArg::OpaqueExecutionContext,
+                 InterpolatedSpecBuiltinArg::Derivatives);
+    } else if (param_name == RS::Hashes::test && type == OIIO::TypeFloat) {
+        spec.set(rs_get_interpolated_test);
+    } else if (const OIIO::ParamValue* p = userdata.find_pv(param_name, type)) {
+        if (p->type().basetype == OIIO::TypeDesc::INT) {
+            if (p->type().aggregate == 1) {
+                spec.set(rs_get_attribute_constant_int, ((int*)p->data())[0]);
+                return;
+            } else if (p->type().aggregate == 2) {
+                spec.set(rs_get_attribute_constant_int2, ((int*)p->data())[0],
+                         ((int*)p->data())[1]);
+                return;
+            } else if (p->type().aggregate == 3) {
+                spec.set(rs_get_attribute_constant_int3, ((int*)p->data())[0],
+                         ((int*)p->data())[1], ((int*)p->data())[2]);
+                return;
+            } else if (p->type().aggregate == 4) {
+                spec.set(rs_get_attribute_constant_int4, ((int*)p->data())[0],
+                         ((int*)p->data())[1], ((int*)p->data())[2],
+                         ((int*)p->data())[3]);
+                return;
+            }
+        } else if (p->type().basetype == OIIO::TypeDesc::FLOAT) {
+            if (p->type().aggregate == 1) {
+                spec.set(rs_get_attribute_constant_float,
+                         ((float*)p->data())[0],
+                         InterpolatedSpecBuiltinArg::Derivatives);
+                return;
+            } else if (p->type().aggregate == 2) {
+                spec.set(rs_get_attribute_constant_float2,
+                         ((float*)p->data())[0], ((float*)p->data())[1],
+                         InterpolatedSpecBuiltinArg::Derivatives);
+                return;
+            } else if (p->type().aggregate == 3) {
+                spec.set(rs_get_attribute_constant_float3,
+                         ((float*)p->data())[0], ((float*)p->data())[1],
+                         ((float*)p->data())[2],
+                         InterpolatedSpecBuiltinArg::Derivatives);
+                return;
+            } else if (p->type().aggregate == 4) {
+                spec.set(rs_get_attribute_constant_float4,
+                         ((float*)p->data())[0], ((float*)p->data())[1],
+                         ((float*)p->data())[2], ((float*)p->data())[3],
+                         InterpolatedSpecBuiltinArg::Derivatives);
+                return;
+            }
+        }
+    }
+}
+
+
+
 bool
 SimpleRenderer::trace(TraceOpt& options, ShaderGlobals* sg, const OSL::Vec3& P,
                       const OSL::Vec3& dPdx, const OSL::Vec3& dPdy,
@@ -711,7 +833,7 @@ SimpleRenderer::getmessage(ShaderGlobals* sg, ustringhash source_,
         }
         if (name == ustring("geom:name")) {
             if (type == TypeString) {
-                *reinterpret_cast<ustring*>(val) = ustring("teapot");
+                *reinterpret_cast<ustring*>(val) = ustringhash("teapot");
             }
         }
         if (name == ustring("N")) {
@@ -769,7 +891,7 @@ SimpleRenderer::get_camera_projection(ShaderGlobals* /*sg*/, bool /*derivs*/,
                                       ustringhash /*name*/, void* val)
 {
     if (type == TypeString) {
-        ((ustring*)val)[0] = m_projection;
+        ((ustringhash*)val)[0] = m_projection;
         return true;
     }
     return false;
@@ -921,12 +1043,13 @@ SimpleRenderer::get_camera_screen_window(ShaderGlobals* /*sg*/, bool derivs,
 
 
 bool
-SimpleRenderer::add_output(string_view varname, string_view filename,
+SimpleRenderer::add_output(string_view varname_, string_view filename,
                            TypeDesc datatype, int nchannels)
 {
     // FIXME: use name to figure out
+    ustring varname_us(varname_);
     OIIO::ImageSpec spec(m_xres, m_yres, nchannels, datatype);
-    m_outputvars.emplace_back(varname);
+    m_outputvars.emplace_back(varname_us);
     m_outputbufs.emplace_back(
         new OIIO::ImageBuf(filename, spec, OIIO::InitializePixels::Yes));
     // OIIO::ImageBufAlgo::zero (*m_outputbufs.back());
@@ -947,7 +1070,7 @@ SimpleRenderer::export_state(RenderState& state) const
                                           0.0, 0.0, 0.0, 1.0, 0.0, 0.0, 0.0,
                                           0.0, 1.0);
     //perspective is not  a member of StringParams (i.e not in strdecls.h)
-    state.projection  = u_perspective;
+    state.projection  = RS::Hashes::perspective;
     state.pixelaspect = m_pixelaspect;
     std::copy_n(m_screen_window, 4, state.screen_window);
     std::copy_n(m_shutter, 2, state.shutter);
@@ -1009,4 +1132,4 @@ SimpleRenderer::filefmt(OSL::ShaderGlobals* sg, OSL::ustringhash filename_hash,
 }
 
 
-OSL_NAMESPACE_EXIT
+OSL_NAMESPACE_END
